cc -I $PREFIX/include -L $PREFIX/lib test.c -lmpir -Wl,-rpath,$PREFIX/lib -o test.out
./test.out


set -ex



test -f $PREFIX/include/mpir.h
test -f $PREFIX/include/mpirxx.h
test -f $PREFIX/lib/libmpir.a
test -f $PREFIX/lib/libmpirxx.a
test -f $PREFIX/lib/libmpir.dylib
test -f $PREFIX/lib/libmpirxx.dylib
exit 0
